@@ -28,16 +28,16 @@ import sqlalchemy as sa
 from alembic import op
 
 # revision identifiers, used by Alembic.
-revision = '561833c1c74b'
-down_revision = '40e67319e3a9'
+revision = "561833c1c74b"
+down_revision = "40e67319e3a9"
 branch_labels = None
 depends_on = None
-airflow_version = '1.6.2'
+airflow_version = "1.6.2"
 
 
 def upgrade():
-    op.add_column('user', sa.Column('password', sa.String(255)))
+    op.add_column("user", sa.Column("password", sa.String(255)))
 
 
 def downgrade():
-    op.drop_column('user', 'password')
+    op.drop_column("user", "password")
