@@ -20,15 +20,17 @@ from __future__ import annotations
 import os
 import shutil
 import warnings
-from typing import Container, Sequence
+from functools import cached_property
+from typing import TYPE_CHECKING, Container, Sequence
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException, AirflowSkipException
 from airflow.hooks.subprocess import SubprocessHook
 from airflow.models.baseoperator import BaseOperator
-from airflow.utils.context import Context
 from airflow.utils.operator_helpers import context_to_airflow_vars
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class BashOperator(BaseOperator):
     r"""
@@ -160,7 +162,7 @@ class BashOperator(BaseOperator):
             skip_on_exit_code
             if isinstance(skip_on_exit_code, Container)
             else [skip_on_exit_code]
-            if skip_on_exit_code
+            if skip_on_exit_code is not None
             else []
         )
         self.cwd = cwd
@@ -172,7 +174,7 @@ class BashOperator(BaseOperator):
         return SubprocessHook()
 
     def get_env(self, context):
-        """Builds the set of environment variables to be exposed for the bash command."""
+        """Build the set of environment variables to be exposed for the bash command."""
         system_env = os.environ.copy()
         env = self.env
         if env is None:
@@ -204,8 +206,8 @@ class BashOperator(BaseOperator):
             output_encoding=self.output_encoding,
             cwd=self.cwd,
         )
-        if self.skip_on_exit_code is not None and result.exit_code in self.skip_on_exit_code:
-            raise AirflowSkipException(f"Bash command returned exit code {self.skip_on_exit_code}. Skipping.")
+        if result.exit_code in self.skip_on_exit_code:
+            raise AirflowSkipException(f"Bash command returned exit code {result.exit_code}. Skipping.")
         elif result.exit_code != 0:
             raise AirflowException(
                 f"Bash command failed. The command returned a non-zero exit code {result.exit_code}."
