@@ -28,7 +28,7 @@ from __future__ import annotations
 
 import itertools
 import random
-from time import sleep
+import time
 from typing import TYPE_CHECKING, Callable
 
 import botocore.client
@@ -549,19 +549,16 @@ class BatchClientHook(AwsBaseHook):
             delay = random.uniform(BatchClientHook.DEFAULT_DELAY_MIN, BatchClientHook.DEFAULT_DELAY_MAX)
         else:
             delay = BatchClientHook.add_jitter(delay)
-        sleep(delay)
+        time.sleep(delay)
 
     @staticmethod
     def exponential_delay(tries: int) -> float:
         """
-        An exponential back-off delay, with random jitter.
+        Apply an exponential back-off delay, with random jitter.
 
         There is a maximum interval of 10 minutes (with random jitter between 3 and 10 minutes).
         This is used in the :py:meth:`.poll_for_job_status` method.
 
-        :param tries: Number of tries
-
-
         Examples of behavior:
 
         .. code-block:: python
@@ -591,6 +588,8 @@ class BatchClientHook(AwsBaseHook):
 
             - https://docs.aws.amazon.com/general/latest/gr/api-retries.html
             - https://aws.amazon.com/blogs/architecture/exponential-backoff-and-jitter/
+
+        :param tries: Number of tries
         """
         max_interval = 600.0  # results in 3 to 10 minute delay
         delay = 1 + pow(tries * 0.6, 2)
