@@ -17,16 +17,50 @@
 # under the License.
 from __future__ import annotations
 
-from datetime import datetime
+from datetime import date, datetime, timedelta
 from functools import cached_property
+from typing import TYPE_CHECKING, Any
 
 import watchtower
 
 from airflow.configuration import conf
 from airflow.providers.amazon.aws.hooks.logs import AwsLogsHook
+from airflow.providers.amazon.aws.utils import datetime_to_epoch_utc_ms
 from airflow.utils.log.file_task_handler import FileTaskHandler
 from airflow.utils.log.logging_mixin import LoggingMixin
 
+if TYPE_CHECKING:
+    from airflow.models import TaskInstance
+
+
+def json_serialize_legacy(value: Any) -> str | None:
+    """
+    JSON serializer replicating legacy watchtower behavior.
+
+    The legacy `watchtower@2.0.1` json serializer function that serialized
+    datetime objects as ISO format and all other non-JSON-serializable to `null`.
+
+    :param value: the object to serialize
+    :return: string representation of `value` if it is an instance of datetime or `None` otherwise
+    """
+    if isinstance(value, (date, datetime)):
+        return value.isoformat()
+    else:
+        return None
+
+
+def json_serialize(value: Any) -> str | None:
+    """
+    JSON serializer replicating current watchtower behavior.
+
+    This provides customers with an accessible import,
+    `airflow.providers.amazon.aws.log.cloudwatch_task_handler.json_serialize`
+
+    :param value: the object to serialize
+    :return: string representation of `value`
+    """
+    return watchtower._json_serialize_default(value)
+
 
 class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
     """
@@ -64,11 +98,13 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
 
     def set_context(self, ti):
         super().set_context(ti)
+        self.json_serialize = conf.getimport("aws", "cloudwatch_task_handler_json_serializer")
         self.handler = watchtower.CloudWatchLogHandler(
             log_group_name=self.log_group,
             log_stream_name=self._render_filename(ti, ti.try_number),
             use_queues=not getattr(ti, "is_trigger_log_context", False),
             boto3_client=self.hook.get_conn(),
+            json_serialize_default=self.json_serialize,
         )
 
     def close(self):
@@ -90,7 +126,8 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
         try:
             return (
                 f"*** Reading remote log from Cloudwatch log_group: {self.log_group} "
-                f"log_stream: {stream_name}.\n{self.get_cloudwatch_logs(stream_name=stream_name)}\n",
+                f"log_stream: {stream_name}.\n"
+                f"{self.get_cloudwatch_logs(stream_name=stream_name, task_instance=task_instance)}\n",
                 {"end_of_log": True},
             )
         except Exception as e:
@@ -103,17 +140,25 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
             log += local_log
             return log, metadata
 
-    def get_cloudwatch_logs(self, stream_name: str) -> str:
+    def get_cloudwatch_logs(self, stream_name: str, task_instance: TaskInstance) -> str:
         """
         Return all logs from the given log stream.
 
         :param stream_name: name of the Cloudwatch log stream to get all logs from
+        :param task_instance: the task instance to get logs about
         :return: string of all logs from the given log stream
         """
+        # If there is an end_date to the task instance, fetch logs until that date + 30 seconds
+        # 30 seconds is an arbitrary buffer so that we don't miss any logs that were emitted
+        end_time = (
+            None
+            if task_instance.end_date is None
+            else datetime_to_epoch_utc_ms(task_instance.end_date + timedelta(seconds=30))
+        )
         events = self.hook.get_log_events(
             log_group=self.log_group,
             log_stream_name=stream_name,
-            start_from_head=True,
+            end_time=end_time,
         )
         return "\n".join(self._event_to_str(event) for event in events)
 
