@@ -22,7 +22,9 @@ import os
 import warnings
 from typing import TYPE_CHECKING, Sequence
 
-from airflow.exceptions import AirflowProviderDeprecationWarning
+from packaging.version import Version
+
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -39,7 +41,8 @@ class GCSToS3Operator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:GCSToS3Operator`
 
-    :param bucket: The Google Cloud Storage bucket to find the objects. (templated)
+    :param gcs_bucket: The Google Cloud Storage bucket to find the objects. (templated)
+    :param bucket: (Deprecated) Use ``gcs_bucket`` instead.
     :param prefix: Prefix string which filters objects whose name begin with
         this prefix. (templated)
     :param delimiter: (Deprecated) The delimiter by which you want to filter the objects. (templated)
@@ -85,7 +88,7 @@ class GCSToS3Operator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        "bucket",
+        "gcs_bucket",
         "prefix",
         "delimiter",
         "dest_s3_key",
@@ -97,7 +100,8 @@ class GCSToS3Operator(BaseOperator):
     def __init__(
         self,
         *,
-        bucket: str,
+        gcs_bucket: str | None = None,
+        bucket: str | None = None,
         prefix: str | None = None,
         delimiter: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
@@ -115,15 +119,19 @@ class GCSToS3Operator(BaseOperator):
     ) -> None:
         super().__init__(**kwargs)
 
-        self.bucket = bucket
-        self.prefix = prefix
-        if delimiter:
+        if bucket:
             warnings.warn(
-                "Usage of 'delimiter' is deprecated, please use 'match_glob' instead",
+                "The ``bucket`` parameter is deprecated and will be removed in a future version. "
+                "Please use ``gcs_bucket`` instead.",
                 AirflowProviderDeprecationWarning,
                 stacklevel=2,
             )
-        self.delimiter = delimiter
+            self.gcs_bucket = bucket
+        if gcs_bucket:
+            self.gcs_bucket = gcs_bucket
+        if not (bucket or gcs_bucket):
+            raise ValueError("You must pass either ``bucket`` or ``gcs_bucket``.")
+        self.prefix = prefix
         self.gcp_conn_id = gcp_conn_id
         self.dest_aws_conn_id = dest_aws_conn_id
         self.dest_s3_key = dest_s3_key
@@ -133,6 +141,27 @@ class GCSToS3Operator(BaseOperator):
         self.dest_s3_extra_args = dest_s3_extra_args or {}
         self.s3_acl_policy = s3_acl_policy
         self.keep_directory_structure = keep_directory_structure
+        try:
+            from airflow.providers.google import __version__
+
+            if Version(__version__) >= Version("10.3.0"):
+                self.__is_match_glob_supported = True
+            else:
+                self.__is_match_glob_supported = False
+        except ImportError:  # __version__ was added in 10.1.0, so this means it's < 10.3.0
+            self.__is_match_glob_supported = False
+        if self.__is_match_glob_supported:
+            if delimiter:
+                warnings.warn(
+                    "Usage of 'delimiter' is deprecated, please use 'match_glob' instead",
+                    AirflowProviderDeprecationWarning,
+                    stacklevel=2,
+                )
+        elif match_glob:
+            raise AirflowException(
+                "The 'match_glob' parameter requires 'apache-airflow-providers-google>=10.3.0'."
+            )
+        self.delimiter = delimiter
         self.match_glob = match_glob
         self.gcp_user_project = gcp_user_project
 
@@ -145,18 +174,21 @@ class GCSToS3Operator(BaseOperator):
 
         self.log.info(
             "Getting list of the files. Bucket: %s; Delimiter: %s; Prefix: %s",
-            self.bucket,
+            self.gcs_bucket,
             self.delimiter,
             self.prefix,
         )
 
-        gcs_files = gcs_hook.list(
-            bucket_name=self.bucket,
-            prefix=self.prefix,
-            delimiter=self.delimiter,
-            match_glob=self.match_glob,
-            user_project=self.gcp_user_project,
-        )
+        list_kwargs = {
+            "bucket_name": self.gcs_bucket,
+            "prefix": self.prefix,
+            "delimiter": self.delimiter,
+            "user_project": self.gcp_user_project,
+        }
+        if self.__is_match_glob_supported:
+            list_kwargs["match_glob"] = self.match_glob
+
+        gcs_files = gcs_hook.list(**list_kwargs)  # type: ignore
 
         s3_hook = S3Hook(
             aws_conn_id=self.dest_aws_conn_id, verify=self.dest_verify, extra_args=self.dest_s3_extra_args
@@ -174,12 +206,12 @@ class GCSToS3Operator(BaseOperator):
             # filter all the objects (return empty list) instead of empty
             # prefix returning all the objects
             if prefix:
-                prefix = prefix if prefix.endswith("/") else f"{prefix}/"
+                prefix = prefix.rstrip("/") + "/"
             # look for the bucket and the prefix to avoid look into
             # parent directories/keys
             existing_files = s3_hook.list_keys(bucket_name, prefix=prefix)
             # in case that no files exists, return an empty array to avoid errors
-            existing_files = existing_files if existing_files is not None else []
+            existing_files = existing_files or []
             # remove the prefix for the existing files to allow the match
             existing_files = [file.replace(prefix, "", 1) for file in existing_files]
             gcs_files = list(set(gcs_files) - set(existing_files))
@@ -187,7 +219,7 @@ class GCSToS3Operator(BaseOperator):
         if gcs_files:
             for file in gcs_files:
                 with gcs_hook.provide_file(
-                    object_name=file, bucket_name=self.bucket, user_project=self.gcp_user_project
+                    object_name=file, bucket_name=self.gcs_bucket, user_project=self.gcp_user_project
                 ) as local_tmp_file:
                     dest_key = os.path.join(self.dest_s3_key, file)
                     self.log.info("Saving file to %s", dest_key)
