@@ -21,15 +21,16 @@ import datetime
 import warnings
 from asyncio import CancelledError
 from enum import Enum
-from typing import Any, AsyncIterator
-
-from kubernetes_asyncio.client.models import V1Pod
+from typing import TYPE_CHECKING, Any, AsyncIterator
 
 from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.providers.cncf.kubernetes.hooks.kubernetes import AsyncKubernetesHook
 from airflow.providers.cncf.kubernetes.utils.pod_manager import OnFinishAction, PodPhase
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 
+if TYPE_CHECKING:
+    from kubernetes_asyncio.client.models import V1Pod
+
 
 class ContainerState(str, Enum):
     """
@@ -82,6 +83,7 @@ class KubernetesPodTrigger(BaseTrigger):
         in_cluster: bool | None = None,
         get_logs: bool = True,
         startup_timeout: int = 120,
+        startup_check_interval: int = 1,
         on_finish_action: str = "delete_pod",
         should_delete_pod: bool | None = None,
     ):
@@ -97,11 +99,13 @@ class KubernetesPodTrigger(BaseTrigger):
         self.in_cluster = in_cluster
         self.get_logs = get_logs
         self.startup_timeout = startup_timeout
+        self.startup_check_interval = startup_check_interval
 
         if should_delete_pod is not None:
             warnings.warn(
                 "`should_delete_pod` parameter is deprecated, please use `on_finish_action`",
-                AirflowProviderDeprecationWarning,
+                category=AirflowProviderDeprecationWarning,
+                stacklevel=2,
             )
             self.on_finish_action = (
                 OnFinishAction.DELETE_POD if should_delete_pod else OnFinishAction.KEEP_POD
@@ -115,7 +119,7 @@ class KubernetesPodTrigger(BaseTrigger):
         self._since_time = None
 
     def serialize(self) -> tuple[str, dict[str, Any]]:
-        """Serializes KubernetesCreatePodTrigger arguments and classpath."""
+        """Serialize KubernetesCreatePodTrigger arguments and classpath."""
         return (
             "airflow.providers.cncf.kubernetes.triggers.pod.KubernetesPodTrigger",
             {
@@ -136,11 +140,11 @@ class KubernetesPodTrigger(BaseTrigger):
         )
 
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
-        """Gets current pod status and yields a TriggerEvent."""
+        """Get current pod status and yield a TriggerEvent."""
         hook = self._get_async_hook()
         self.log.info("Checking pod %r in namespace %r.", self.pod_name, self.pod_namespace)
-        while True:
-            try:
+        try:
+            while True:
                 pod = await hook.get_pod(
                     name=self.pod_name,
                     namespace=self.pod_namespace,
@@ -165,7 +169,7 @@ class KubernetesPodTrigger(BaseTrigger):
                 elif self.should_wait(pod_phase=pod_status, container_state=container_state):
                     self.log.info("Container is not completed and still working.")
 
-                    if pod_status == PodPhase.PENDING and container_state == ContainerState.UNDEFINED:
+                    if pod_status == PodPhase.PENDING and container_state != ContainerState.RUNNING:
                         delta = datetime.datetime.now(tz=datetime.timezone.utc) - self.trigger_start_time
                         if delta.total_seconds() >= self.startup_timeout:
                             message = (
@@ -181,9 +185,12 @@ class KubernetesPodTrigger(BaseTrigger):
                                 }
                             )
                             return
-
-                    self.log.info("Sleeping for %s seconds.", self.poll_interval)
-                    await asyncio.sleep(self.poll_interval)
+                        else:
+                            self.log.info("Sleeping for %s seconds.", self.startup_check_interval)
+                            await asyncio.sleep(self.startup_check_interval)
+                    else:
+                        self.log.info("Sleeping for %s seconds.", self.poll_interval)
+                        await asyncio.sleep(self.poll_interval)
                 else:
                     yield TriggerEvent(
                         {
@@ -194,40 +201,38 @@ class KubernetesPodTrigger(BaseTrigger):
                         }
                     )
                     return
-            except CancelledError:
-                # That means that task was marked as failed
-                if self.get_logs:
-                    self.log.info("Outputting container logs...")
-                    await self._get_async_hook().read_logs(
-                        name=self.pod_name,
-                        namespace=self.pod_namespace,
-                    )
-                if self.on_finish_action == OnFinishAction.DELETE_POD:
-                    self.log.info("Deleting pod...")
-                    await self._get_async_hook().delete_pod(
-                        name=self.pod_name,
-                        namespace=self.pod_namespace,
-                    )
-                yield TriggerEvent(
-                    {
-                        "name": self.pod_name,
-                        "namespace": self.pod_namespace,
-                        "status": "cancelled",
-                        "message": "Pod execution was cancelled",
-                    }
+        except CancelledError:
+            # That means that task was marked as failed
+            if self.get_logs:
+                self.log.info("Outputting container logs...")
+                await self._get_async_hook().read_logs(
+                    name=self.pod_name,
+                    namespace=self.pod_namespace,
                 )
-                return
-            except Exception as e:
-                self.log.exception("Exception occurred while checking pod phase:")
-                yield TriggerEvent(
-                    {
-                        "name": self.pod_name,
-                        "namespace": self.pod_namespace,
-                        "status": "error",
-                        "message": str(e),
-                    }
+            if self.on_finish_action == OnFinishAction.DELETE_POD:
+                self.log.info("Deleting pod...")
+                await self._get_async_hook().delete_pod(
+                    name=self.pod_name,
+                    namespace=self.pod_namespace,
                 )
-                return
+            yield TriggerEvent(
+                {
+                    "name": self.pod_name,
+                    "namespace": self.pod_namespace,
+                    "status": "cancelled",
+                    "message": "Pod execution was cancelled",
+                }
+            )
+        except Exception as e:
+            self.log.exception("Exception occurred while checking pod phase:")
+            yield TriggerEvent(
+                {
+                    "name": self.pod_name,
+                    "namespace": self.pod_namespace,
+                    "status": "error",
+                    "message": str(e),
+                }
+            )
 
     def _get_async_hook(self) -> AsyncKubernetesHook:
         if self._hook is None:
