@@ -145,8 +145,8 @@ class DatabricksSqlHook(BaseDatabricksHook, DbApiHook):
             )
         return self._sql_conn
 
-    @overload
-    def run(
+    @overload  # type: ignore[override]
+    def run(  # type: ignore[overload-overlap]
         self,
         sql: str | Iterable[str],
         autocommit: bool = ...,
@@ -220,7 +220,7 @@ class DatabricksSqlHook(BaseDatabricksHook, DbApiHook):
                 self.set_autocommit(conn, autocommit)
 
                 with closing(conn.cursor()) as cur:
-                    self._run_command(cur, sql_statement, parameters)
+                    self._run_command(cur, sql_statement, parameters)  # type: ignore[attr-defined]
                     if handler is not None:
                         result = self._make_serializable(handler(cur))
                         if return_single_query_results(sql, return_last, split_statements):
