@@ -18,13 +18,15 @@
 """
 Example Airflow DAG that shows how to use FacebookAdsReportToGcsOperator.
 """
+from __future__ import annotations
+
 import os
 from datetime import datetime
 
 from facebook_business.adobjects.adsinsights import AdsInsights
 
-from airflow import models
 from airflow.models.baseoperator import chain
+from airflow.models.dag import DAG
 from airflow.providers.google.cloud.operators.bigquery import (
     BigQueryCreateEmptyDatasetOperator,
     BigQueryCreateEmptyTableOperator,
@@ -52,15 +54,14 @@ FIELDS = [
     AdsInsights.Field.clicks,
     AdsInsights.Field.impressions,
 ]
-PARAMETERS = {'level': 'ad', 'date_preset': 'yesterday'}
+PARAMETERS = {"level": "ad", "date_preset": "yesterday"}
 # [END howto_FB_ADS_variables]
 
-with models.DAG(
+with DAG(
     "example_facebook_ads_to_gcs",
     start_date=datetime(2021, 1, 1),
     catchup=False,
 ) as dag:
-
     create_bucket = GCSCreateBucketOperator(
         task_id="create_bucket",
         bucket_name=GCS_BUCKET,
@@ -77,18 +78,18 @@ with models.DAG(
         dataset_id=DATASET_NAME,
         table_id=TABLE_NAME,
         schema_fields=[
-            {'name': 'campaign_name', 'type': 'STRING', 'mode': 'NULLABLE'},
-            {'name': 'campaign_id', 'type': 'STRING', 'mode': 'NULLABLE'},
-            {'name': 'ad_id', 'type': 'STRING', 'mode': 'NULLABLE'},
-            {'name': 'clicks', 'type': 'STRING', 'mode': 'NULLABLE'},
-            {'name': 'impressions', 'type': 'STRING', 'mode': 'NULLABLE'},
+            {"name": "campaign_name", "type": "STRING", "mode": "NULLABLE"},
+            {"name": "campaign_id", "type": "STRING", "mode": "NULLABLE"},
+            {"name": "ad_id", "type": "STRING", "mode": "NULLABLE"},
+            {"name": "clicks", "type": "STRING", "mode": "NULLABLE"},
+            {"name": "impressions", "type": "STRING", "mode": "NULLABLE"},
         ],
     )
 
     # [START howto_operator_facebook_ads_to_gcs]
     run_operator = FacebookAdsReportToGcsOperator(
-        task_id='run_fetch_data',
-        owner='airflow',
+        task_id="run_fetch_data",
+        owner="airflow",
         bucket_name=GCS_BUCKET,
         parameters=PARAMETERS,
         fields=FIELDS,
@@ -98,11 +99,11 @@ with models.DAG(
     # [END howto_operator_facebook_ads_to_gcs]
 
     load_csv = GCSToBigQueryOperator(
-        task_id='gcs_to_bq_example',
+        task_id="gcs_to_bq_example",
         bucket=GCS_BUCKET,
         source_objects=[GCS_OBJ_PATH],
         destination_project_dataset_table=f"{DATASET_NAME}.{TABLE_NAME}",
-        write_disposition='WRITE_TRUNCATE',
+        write_disposition="WRITE_TRUNCATE",
     )
 
     read_data_from_gcs_many_chunks = BigQueryInsertJobOperator(
