@@ -18,7 +18,7 @@
 """
 This module contains a Google Kubernetes Engine Hook.
 
-.. spelling::
+.. spelling:word-list::
 
     gapic
     enums
@@ -29,13 +29,12 @@ import contextlib
 import json
 import time
 import warnings
-from typing import Sequence
+from functools import cached_property
+from typing import TYPE_CHECKING, Sequence
 
-import google.auth.credentials
 from gcloud.aio.auth import Token
 from google.api_core.exceptions import NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.auth.transport import requests as google_requests
 
 # not sure why but mypy complains on missing `container_v1` but it is clearly there and is importable
@@ -44,14 +43,12 @@ from google.cloud.container_v1 import ClusterManagerAsyncClient, ClusterManagerC
 from google.cloud.container_v1.types import Cluster, Operation
 from kubernetes import client
 from kubernetes_asyncio import client as async_client
-from kubernetes_asyncio.client.models import V1Pod
 from kubernetes_asyncio.config.kube_config import FileOrData
 from urllib3.exceptions import HTTPError
 
 from airflow import version
-from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException
-from airflow.kubernetes.pod_generator_deprecated import PodDefaults
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.providers.cncf.kubernetes.utils.pod_manager import PodOperatorHookProtocol
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import (
     PROVIDE_PROJECT_ID,
@@ -59,12 +56,16 @@ from airflow.providers.google.common.hooks.base_google import (
     GoogleBaseHook,
 )
 
+if TYPE_CHECKING:
+    import google.auth.credentials
+    from google.api_core.retry import Retry
+    from kubernetes_asyncio.client.models import V1Pod
+
 OPERATIONAL_POLL_INTERVAL = 15
 
 
 class GKEHook(GoogleBaseHook):
-    """
-    Hook for managing Google Kubernetes Engine cluster APIs.
+    """Google Kubernetes Engine cluster APIs.
 
     All the methods in the hook where project_id is used must be called with
     keyword arguments rather than positional.
@@ -73,20 +74,24 @@ class GKEHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         location: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._client: ClusterManagerClient | None = None
         self.location = location
 
     def get_cluster_manager_client(self) -> ClusterManagerClient:
-        """Returns ClusterManagerClient."""
+        """Create or get a ClusterManagerClient."""
         if self._client is None:
             self._client = ClusterManagerClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
@@ -96,7 +101,7 @@ class GKEHook(GoogleBaseHook):
     def get_conn(self) -> container_v1.ClusterManagerClient:
         warnings.warn(
             "The get_conn method has been deprecated. You should use the get_cluster_manager_client method.",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
         )
         return self.get_cluster_manager_client()
 
@@ -105,23 +110,23 @@ class GKEHook(GoogleBaseHook):
     def get_client(self) -> ClusterManagerClient:
         warnings.warn(
             "The get_client method has been deprecated. You should use the get_conn method.",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
         )
         return self.get_conn()
 
     def wait_for_operation(self, operation: Operation, project_id: str | None = None) -> Operation:
-        """
-        Given an operation, continuously fetches the status from Google Cloud until either
-        completion or an error occurring
+        """Continuously fetch the status from Google Cloud.
 
-        :param operation: The Operation to wait for
-        :param project_id: Google Cloud project ID
-        :return: A new, updated operation fetched from Google Cloud
+        This is done until the given operation completes, or raises an error.
+
+        :param operation: The Operation to wait for.
+        :param project_id: Google Cloud project ID.
+        :return: A new, updated operation fetched from Google Cloud.
         """
         self.log.info("Waiting for OPERATION_NAME %s", operation.name)
         time.sleep(OPERATIONAL_POLL_INTERVAL)
         while operation.status != Operation.Status.DONE:
-            if operation.status == Operation.Status.RUNNING or operation.status == Operation.Status.PENDING:
+            if operation.status in (Operation.Status.RUNNING, Operation.Status.PENDING):
                 time.sleep(OPERATIONAL_POLL_INTERVAL)
             else:
                 raise exceptions.GoogleCloudError(f"Operation has failed with status: {operation.status}")
@@ -130,8 +135,7 @@ class GKEHook(GoogleBaseHook):
         return operation
 
     def get_operation(self, operation_name: str, project_id: str | None = None) -> Operation:
-        """
-        Fetches the operation from Google Cloud
+        """Get an operation from Google Cloud.
 
         :param operation_name: Name of operation to fetch
         :param project_id: Google Cloud project ID
@@ -146,8 +150,7 @@ class GKEHook(GoogleBaseHook):
 
     @staticmethod
     def _append_label(cluster_proto: Cluster, key: str, val: str) -> Cluster:
-        """
-        Append labels to provided Cluster Protobuf
+        """Append labels to provided Cluster Protobuf.
 
         Labels must fit the regex ``[a-z]([-a-z0-9]*[a-z0-9])?`` (current
          airflow version string follows semantic versioning spec: x.y.z).
@@ -171,24 +174,23 @@ class GKEHook(GoogleBaseHook):
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
     ) -> Operation | None:
-        """
-        Deletes the cluster, including the Kubernetes endpoint and all
-        worker nodes. Firewalls and routes that were configured during
-        cluster creation are also deleted. Other Google Compute Engine
-        resources that might be in use by the cluster (e.g. load balancer
-        resources) will not be deleted if they were not present at the
-        initial create time.
+        """Deletes the cluster, the Kubernetes endpoint, and all worker nodes.
 
-        :param name: The name of the cluster to delete
-        :param project_id: Google Cloud project ID
-        :param wait_to_complete: A boolean value which makes method to sleep while
-            operation of deletion is not finished.
+        Firewalls and routes that were configured during cluster creation are
+        also deleted. Other Google Compute Engine resources that might be in use
+        by the cluster (e.g. load balancer resources) will not be deleted if
+        they were not present at the initial create time.
+
+        :param name: The name of the cluster to delete.
+        :param project_id: Google Cloud project ID.
+        :param wait_to_complete: If *True*, wait until the deletion is finished
+            before returning.
         :param retry: Retry object used to determine when/if to retry requests.
             If None is specified, requests will not be retried.
-        :param timeout: The amount of time, in seconds, to wait for the request to
-            complete. Note that if retry is specified, the timeout applies to each
-            individual attempt.
-        :return: The full url to the delete operation if successful, else None
+        :param timeout: The amount of time, in seconds, to wait for the request
+            to complete. Note that if retry is specified, the timeout applies to
+            each individual attempt.
+        :return: The full url to the delete operation if successful, else None.
         """
         self.log.info("Deleting (project_id=%s, location=%s, cluster_id=%s)", project_id, self.location, name)
 
@@ -215,26 +217,27 @@ class GKEHook(GoogleBaseHook):
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
     ) -> Operation | Cluster:
-        """
-        Creates a cluster, consisting of the specified number and type of Google Compute
-        Engine instances.
+        """Create a cluster.
+
+        This should consist of the specified number, and the type of Google
+        Compute Engine instances.
 
         :param cluster: A Cluster protobuf or dict. If dict is provided, it must
             be of the same form as the protobuf message
-            :class:`google.cloud.container_v1.types.Cluster`
-        :param project_id: Google Cloud project ID
-        :param wait_to_complete: A boolean value which makes method to sleep while
-            operation of creation is not finished.
+            :class:`google.cloud.container_v1.types.Cluster`.
+        :param project_id: Google Cloud project ID.
+        :param wait_to_complete: A boolean value which makes method to sleep
+            while operation of creation is not finished.
         :param retry: A retry object (``google.api_core.retry.Retry``) used to
-            retry requests.
-            If None is specified, requests will not be retried.
-        :param timeout: The amount of time, in seconds, to wait for the request to
-            complete. Note that if retry is specified, the timeout applies to each
-            individual attempt.
-        :return: The full url to the new, or existing, cluster
-        :raises:
-            ParseError: On JSON parsing problems when trying to convert dict
-            AirflowException: cluster is not dict type nor Cluster proto type
+            retry requests. If None is specified, requests will not be retried.
+        :param timeout: The amount of time, in seconds, to wait for the request
+            to complete. Note that if retry is specified, the timeout applies to
+            each individual attempt.
+        :return: The full url to the new, or existing, cluster.
+        :raises ParseError: On JSON parsing problems when trying to convert
+            dict.
+        :raises AirflowException: cluster is not dict type nor Cluster proto
+            type.
         """
         if isinstance(cluster, dict):
             cluster = Cluster.from_json(json.dumps(cluster))
@@ -269,17 +272,15 @@ class GKEHook(GoogleBaseHook):
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
     ) -> Cluster:
-        """
-        Gets details of specified cluster
+        """Get details of specified cluster.
 
-        :param name: The name of the cluster to retrieve
-        :param project_id: Google Cloud project ID
-        :param retry: A retry object used to retry requests. If None is specified,
-            requests will not be retried.
-        :param timeout: The amount of time, in seconds, to wait for the request to
-            complete. Note that if retry is specified, the timeout applies to each
-            individual attempt.
-        :return: google.cloud.container_v1.types.Cluster
+        :param name: The name of the cluster to retrieve.
+        :param project_id: Google Cloud project ID.
+        :param retry: A retry object used to retry requests. If None is
+            specified, requests will not be retried.
+        :param timeout: The amount of time, in seconds, to wait for the request
+            to complete. Note that if retry is specified, the timeout applies to
+            each individual attempt.
         """
         self.log.info(
             "Fetching cluster (project_id=%s, location=%s, cluster_name=%s)",
@@ -296,20 +297,18 @@ class GKEHook(GoogleBaseHook):
 
 
 class GKEAsyncHook(GoogleBaseAsyncHook):
-    """Hook implemented with usage of asynchronous client of GKE."""
+    """Asynchronous client of GKE."""
 
     sync_hook_class = GKEHook
 
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         location: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._client: ClusterManagerAsyncClient | None = None
@@ -329,8 +328,7 @@ class GKEAsyncHook(GoogleBaseAsyncHook):
         operation_name: str,
         project_id: str = PROVIDE_PROJECT_ID,
     ) -> Operation:
-        """
-        Fetches the operation from Google Cloud.
+        """Fetch an operation from Google Cloud.
 
         :param operation_name: Name of operation to fetch.
         :param project_id: Google Cloud project ID.
@@ -345,8 +343,8 @@ class GKEAsyncHook(GoogleBaseAsyncHook):
         )
 
 
-class GKEPodHook(GoogleBaseHook):
-    """Hook for managing Google Kubernetes Engine pod APIs."""
+class GKEPodHook(GoogleBaseHook, PodOperatorHookProtocol):
+    """Google Kubernetes Engine pod APIs."""
 
     def __init__(
         self,
@@ -371,15 +369,32 @@ class GKEPodHook(GoogleBaseHook):
     def is_in_cluster(self) -> bool:
         return False
 
-    @staticmethod
-    def get_xcom_sidecar_container_image():
-        """Returns the xcom sidecar image that defined in the connection"""
-        return PodDefaults.SIDECAR_CONTAINER.image
+    def get_namespace(self):
+        """Get the namespace configured by the Airflow connection."""
+
+    def _get_namespace(self):
+        """For compatibility with KubernetesHook. Deprecated; do not use."""
+
+    def get_xcom_sidecar_container_image(self):
+        """Get the xcom sidecar image defined in the connection.
+
+        Implemented for compatibility with KubernetesHook.
+        """
+
+    def get_xcom_sidecar_container_resources(self):
+        """Get the xcom sidecar resources defined in the connection.
+
+        Implemented for compatibility with KubernetesHook.
+        """
 
     def get_conn(self) -> client.ApiClient:
         configuration = self._get_config()
+        configuration.refresh_api_key_hook = self._refresh_api_key_hook
         return client.ApiClient(configuration)
 
+    def _refresh_api_key_hook(self, configuration: client.configuration.Configuration):
+        configuration.api_key = {"authorization": self._get_token(self.get_credentials())}
+
     def _get_config(self) -> client.configuration.Configuration:
         configuration = client.Configuration(
             host=self._cluster_url,
@@ -402,8 +417,7 @@ class GKEPodHook(GoogleBaseHook):
         return creds.token
 
     def get_pod(self, name: str, namespace: str) -> V1Pod:
-        """
-        Gets pod's object.
+        """Get a pod object.
 
         :param name: Name of the pod.
         :param namespace: Name of the pod's namespace.
@@ -415,31 +429,19 @@ class GKEPodHook(GoogleBaseHook):
 
 
 class GKEPodAsyncHook(GoogleBaseAsyncHook):
-    """
-    Hook for managing Google Kubernetes Engine pods APIs in asynchronous way.
+    """Google Kubernetes Engine pods APIs asynchronously.
 
     :param cluster_url: The URL pointed to the cluster.
-    :param ssl_ca_cert: SSL certificate that is used for authentication to the pod.
+    :param ssl_ca_cert: SSL certificate used for authentication to the pod.
     """
 
     sync_hook_class = GKEPodHook
     scopes = ["https://www.googleapis.com/auth/cloud-platform"]
 
-    def __init__(
-        self,
-        cluster_url: str,
-        ssl_ca_cert: str,
-        **kwargs,
-    ):
-
+    def __init__(self, cluster_url: str, ssl_ca_cert: str, **kwargs) -> None:
         self._cluster_url = cluster_url
         self._ssl_ca_cert = ssl_ca_cert
-
-        kwargs.update(
-            cluster_url=cluster_url,
-            ssl_ca_cert=ssl_ca_cert,
-        )
-        super().__init__(**kwargs)
+        super().__init__(cluster_url=cluster_url, ssl_ca_cert=ssl_ca_cert, **kwargs)
 
     @contextlib.asynccontextmanager
     async def get_conn(self, token: Token) -> async_client.ApiClient:  # type: ignore[override]
@@ -473,8 +475,7 @@ class GKEPodAsyncHook(GoogleBaseAsyncHook):
         return configuration
 
     async def get_pod(self, name: str, namespace: str) -> V1Pod:
-        """
-        Gets pod's object.
+        """Get a pod object.
 
         :param name: Name of the pod.
         :param namespace: Name of the pod's namespace.
@@ -489,49 +490,48 @@ class GKEPodAsyncHook(GoogleBaseAsyncHook):
             return pod
 
     async def delete_pod(self, name: str, namespace: str):
-        """
-        Deletes pod's object.
+        """Delete a pod.
 
         :param name: Name of the pod.
         :param namespace: Name of the pod's namespace.
         """
-        async with Token(scopes=self.scopes) as token:
-            async with self.get_conn(token) as connection:
-                try:
-                    v1_api = async_client.CoreV1Api(connection)
-                    await v1_api.delete_namespaced_pod(
-                        name=name,
-                        namespace=namespace,
-                        body=client.V1DeleteOptions(),
-                    )
-                except async_client.ApiException as e:
-                    # If the pod is already deleted
-                    if e.status != 404:
-                        raise
+        async with Token(scopes=self.scopes) as token, self.get_conn(token) as connection:
+            try:
+                v1_api = async_client.CoreV1Api(connection)
+                await v1_api.delete_namespaced_pod(
+                    name=name,
+                    namespace=namespace,
+                    body=client.V1DeleteOptions(),
+                )
+            except async_client.ApiException as e:
+                # If the pod is already deleted
+                if e.status != 404:
+                    raise
 
     async def read_logs(self, name: str, namespace: str):
-        """
-        Reads logs inside the pod while starting containers inside. All the logs will be outputted with its
-        timestamp to track the logs after the execution of the pod is completed. The method is used for async
-        output of the logs only in the pod failed it execution or the task was cancelled by the user.
+        """Read logs inside the pod while starting containers inside.
+
+        All the logs will be outputted with its timestamp to track the logs
+        after the execution of the pod is completed. The method is used for
+        async output of the logs only in the pod failed it execution or the task
+        was cancelled by the user.
 
         :param name: Name of the pod.
         :param namespace: Name of the pod's namespace.
         """
-        async with Token(scopes=self.scopes) as token:
-            async with self.get_conn(token) as connection:
-                try:
-                    v1_api = async_client.CoreV1Api(connection)
-                    logs = await v1_api.read_namespaced_pod_log(
-                        name=name,
-                        namespace=namespace,
-                        follow=False,
-                        timestamps=True,
-                    )
-                    logs = logs.splitlines()
-                    for line in logs:
-                        self.log.info("Container logs from %s", line)
-                    return logs
-                except HTTPError:
-                    self.log.exception("There was an error reading the kubernetes API.")
-                    raise
+        async with Token(scopes=self.scopes) as token, self.get_conn(token) as connection:
+            try:
+                v1_api = async_client.CoreV1Api(connection)
+                logs = await v1_api.read_namespaced_pod_log(
+                    name=name,
+                    namespace=namespace,
+                    follow=False,
+                    timestamps=True,
+                )
+                logs = logs.splitlines()
+                for line in logs:
+                    self.log.info("Container logs from %s", line)
+                return logs
+            except HTTPError:
+                self.log.exception("There was an error reading the kubernetes API.")
+                raise
