@@ -15,33 +15,31 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains various Google Cloud Tasks operators
-which allow you to perform basic operations using
-Cloud Tasks queues/tasks.
-"""
+"""Google Cloud Tasks operators which allow you to perform basic operations using Cloud Tasks queues/tasks."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Sequence, Tuple
 
 from google.api_core.exceptions import AlreadyExists
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.tasks_v2.types import Queue, Task
-from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.tasks import CloudTasksHook
 from airflow.providers.google.cloud.links.cloud_tasks import CloudTasksLink, CloudTasksQueueLink
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+    from google.protobuf.field_mask_pb2 import FieldMask
+
     from airflow.utils.context import Context
 
 
 MetaData = Sequence[Tuple[str, str]]
 
 
-class CloudTasksQueueCreateOperator(BaseOperator):
+class CloudTasksQueueCreateOperator(GoogleCloudBaseOperator):
     """
     Creates a queue in Cloud Tasks.
 
@@ -144,7 +142,7 @@ class CloudTasksQueueCreateOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksQueueUpdateOperator(BaseOperator):
+class CloudTasksQueueUpdateOperator(GoogleCloudBaseOperator):
     """
     Updates a queue in Cloud Tasks.
 
@@ -243,7 +241,7 @@ class CloudTasksQueueUpdateOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksQueueGetOperator(BaseOperator):
+class CloudTasksQueueGetOperator(GoogleCloudBaseOperator):
     """
     Gets a queue from Cloud Tasks.
 
@@ -326,7 +324,7 @@ class CloudTasksQueueGetOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksQueuesListOperator(BaseOperator):
+class CloudTasksQueuesListOperator(GoogleCloudBaseOperator):
     """
     Lists queues from Cloud Tasks.
 
@@ -413,7 +411,7 @@ class CloudTasksQueuesListOperator(BaseOperator):
         return [Queue.to_dict(q) for q in queues]
 
 
-class CloudTasksQueueDeleteOperator(BaseOperator):
+class CloudTasksQueueDeleteOperator(GoogleCloudBaseOperator):
     """
     Deletes a queue from Cloud Tasks, even if it has tasks in it.
 
@@ -488,7 +486,7 @@ class CloudTasksQueueDeleteOperator(BaseOperator):
         )
 
 
-class CloudTasksQueuePurgeOperator(BaseOperator):
+class CloudTasksQueuePurgeOperator(GoogleCloudBaseOperator):
     """
     Purges a queue by deleting all of its tasks from Cloud Tasks.
 
@@ -571,7 +569,7 @@ class CloudTasksQueuePurgeOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksQueuePauseOperator(BaseOperator):
+class CloudTasksQueuePauseOperator(GoogleCloudBaseOperator):
     """
     Pauses a queue in Cloud Tasks.
 
@@ -654,7 +652,7 @@ class CloudTasksQueuePauseOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksQueueResumeOperator(BaseOperator):
+class CloudTasksQueueResumeOperator(GoogleCloudBaseOperator):
     """
     Resumes a queue in Cloud Tasks.
 
@@ -737,7 +735,7 @@ class CloudTasksQueueResumeOperator(BaseOperator):
         return Queue.to_dict(queue)
 
 
-class CloudTasksTaskCreateOperator(BaseOperator):
+class CloudTasksTaskCreateOperator(GoogleCloudBaseOperator):
     """
     Creates a task in Cloud Tasks.
 
@@ -837,7 +835,7 @@ class CloudTasksTaskCreateOperator(BaseOperator):
         return Task.to_dict(task)
 
 
-class CloudTasksTaskGetOperator(BaseOperator):
+class CloudTasksTaskGetOperator(GoogleCloudBaseOperator):
     """
     Gets a task from Cloud Tasks.
 
@@ -930,7 +928,7 @@ class CloudTasksTaskGetOperator(BaseOperator):
         return Task.to_dict(task)
 
 
-class CloudTasksTasksListOperator(BaseOperator):
+class CloudTasksTasksListOperator(GoogleCloudBaseOperator):
     """
     Lists the tasks in Cloud Tasks.
 
@@ -1024,7 +1022,7 @@ class CloudTasksTasksListOperator(BaseOperator):
         return [Task.to_dict(t) for t in tasks]
 
 
-class CloudTasksTaskDeleteOperator(BaseOperator):
+class CloudTasksTaskDeleteOperator(GoogleCloudBaseOperator):
     """
     Deletes a task from Cloud Tasks.
 
@@ -1104,7 +1102,7 @@ class CloudTasksTaskDeleteOperator(BaseOperator):
         )
 
 
-class CloudTasksTaskRunOperator(BaseOperator):
+class CloudTasksTaskRunOperator(GoogleCloudBaseOperator):
     """
     Forces to run a task in Cloud Tasks.
 
