@@ -18,10 +18,9 @@
 """This module contains a Google Cloud Data Fusion sensors."""
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Iterable, Sequence
 
-from airflow.exceptions import AirflowException, AirflowNotFoundException
+from airflow.exceptions import AirflowException, AirflowNotFoundException, AirflowSkipException
 from airflow.providers.google.cloud.hooks.datafusion import DataFusionHook
 from airflow.sensors.base import BaseSensorOperator
 
@@ -31,7 +30,7 @@ if TYPE_CHECKING:
 
 class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
     """
-    Check the status of the pipeline in the Google Cloud Data Fusion
+    Check the status of the pipeline in the Google Cloud Data Fusion.
 
     :param pipeline_name: Your pipeline name.
     :param pipeline_id: Your pipeline ID.
@@ -44,9 +43,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -71,7 +67,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         project_id: str | None = None,
         namespace: str = "default",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -85,11 +80,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         self.project_id = project_id
         self.namespace = namespace
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def poke(self, context: Context) -> bool:
@@ -100,7 +90,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         )
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -120,15 +109,23 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
             )
             pipeline_status = pipeline_workflow["status"]
         except AirflowNotFoundException:
-            raise AirflowException("Specified Pipeline ID was not found.")
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            message = "Specified Pipeline ID was not found."
+            if self.soft_fail:
+                raise AirflowSkipException(message)
+            raise AirflowException(message)
         except AirflowException:
             pass  # Because the pipeline may not be visible in system yet
         if pipeline_status is not None:
             if self.failure_statuses and pipeline_status in self.failure_statuses:
-                raise AirflowException(
+                # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+                message = (
                     f"Pipeline with id '{self.pipeline_id}' state is: {pipeline_status}. "
                     f"Terminating sensor..."
                 )
+                if self.soft_fail:
+                    raise AirflowSkipException(message)
+                raise AirflowException(message)
 
         self.log.debug(
             "Current status of the pipeline workflow for %s: %s.", self.pipeline_id, pipeline_status
