@@ -94,8 +94,7 @@ class MySQLToGCSOperator(BaseSQLToGCSOperator):
 
     def convert_type(self, value, schema_type: str, **kwargs):
         """
-        Takes a value from MySQLdb, and converts it to a value that's safe for
-        JSON/Google Cloud Storage/BigQuery.
+        Take a value from MySQLdb and convert it to a value safe for JSON/Google Cloud Storage/BigQuery.
 
         * Datetimes are converted to `str(value)` (`datetime.isoformat(' ')`)
           strings.
