@@ -19,51 +19,42 @@ from __future__ import annotations
 
 import json
 import warnings
-from functools import wraps
+from functools import cached_property
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence, TypedDict
 
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
+from typing_extensions import NotRequired
 
-from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException, AirflowNotFoundException
+from airflow.exceptions import AirflowNotFoundException
 from airflow.hooks.base import BaseHook
 from airflow.providers.slack.utils import ConnectionExtraConfig
 from airflow.utils.helpers import exactly_one
-from airflow.utils.log.secrets_masker import mask_secret
 
 if TYPE_CHECKING:
     from slack_sdk.http_retry import RetryHandler
     from slack_sdk.web.slack_response import SlackResponse
 
 
-def _ensure_prefixes(conn_type):
+class FileUploadTypeDef(TypedDict):
     """
-    Remove when provider min airflow version >= 2.5.0 since this is handled by
-    provider manager from that version.
+    Represents the structure of the file upload data.
+
+    :ivar file: Optional. Path to file which need to be sent.
+    :ivar content: Optional. File contents. If omitting this parameter, you must provide a file.
+    :ivar filename: Optional. Displayed filename.
+    :ivar title: Optional. The title of the uploaded file.
+    :ivar alt_txt: Optional. Description of image for screen-reader.
+    :ivar snippet_type: Optional. Syntax type of the snippet being uploaded.
     """
 
-    def dec(func):
-        @wraps(func)
-        def inner(cls):
-            field_behaviors = func(cls)
-            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
-
-            def _ensure_prefix(field):
-                if field not in conn_attrs and not field.startswith("extra__"):
-                    return f"extra__{conn_type}__{field}"
-                else:
-                    return field
-
-            if "placeholders" in field_behaviors:
-                placeholders = field_behaviors["placeholders"]
-                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
-            return field_behaviors
-
-        return inner
-
-    return dec
+    file: NotRequired[str | None]
+    content: NotRequired[str | None]
+    filename: NotRequired[str | None]
+    title: NotRequired[str | None]
+    alt_txt: NotRequired[str | None]
+    snippet_type: NotRequired[str | None]
 
 
 class SlackHook(BaseHook):
@@ -106,7 +97,6 @@ class SlackHook(BaseHook):
         If not set than default WebClient BASE_URL will use (``https://www.slack.com/api/``).
     :param proxy: Proxy to make the Slack API call.
     :param retry_handlers: List of handlers to customize retry logic in ``slack_sdk.WebClient``.
-    :param token: (deprecated) Slack API Token.
     """
 
     conn_name_attr = "slack_conn_id"
@@ -116,42 +106,34 @@ class SlackHook(BaseHook):
 
     def __init__(
         self,
-        token: str | None = None,
-        slack_conn_id: str | None = None,
+        *,
+        slack_conn_id: str = default_conn_name,
         base_url: str | None = None,
         timeout: int | None = None,
         proxy: str | None = None,
         retry_handlers: list[RetryHandler] | None = None,
         **extra_client_args: Any,
     ) -> None:
-        if not token and not slack_conn_id:
-            raise AirflowException("Either `slack_conn_id` or `token` should be provided.")
-        if token:
-            mask_secret(token)
-            warnings.warn(
-                "Provide token as hook argument deprecated by security reason and will be removed "
-                "in a future releases. Please specify token in `Slack API` connection.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        if not slack_conn_id:
-            warnings.warn(
-                "You have not set parameter `slack_conn_id`. Currently `Slack API` connection id optional "
-                "but in a future release it will mandatory.",
-                FutureWarning,
-                stacklevel=2,
-            )
-
         super().__init__()
-        self._token = token
         self.slack_conn_id = slack_conn_id
         self.base_url = base_url
         self.timeout = timeout
         self.proxy = proxy
         self.retry_handlers = retry_handlers
+        if "token" in extra_client_args:
+            warnings.warn(
+                f"Provide `token` as part of {type(self).__name__!r} parameters is disallowed, "
+                f"please use Airflow Connection.",
+                UserWarning,
+                stacklevel=2,
+            )
+            extra_client_args.pop("token")
+        if "logger" not in extra_client_args:
+            extra_client_args["logger"] = self.log
         self.extra_client_args = extra_client_args
-        if self.extra_client_args.pop("use_session", None) is not None:
-            warnings.warn("`use_session` has no affect in slack_sdk.WebClient.", UserWarning, stacklevel=2)
+
+        # Use for caching channels result
+        self._channels_mapping: dict[str, str] = {}
 
     @cached_property
     def client(self) -> WebClient:
@@ -164,24 +146,15 @@ class SlackHook(BaseHook):
 
     def _get_conn_params(self) -> dict[str, Any]:
         """Fetch connection params as a dict and merge it with hook parameters."""
-        conn = self.get_connection(self.slack_conn_id) if self.slack_conn_id else None
-        conn_params: dict[str, Any] = {"retry_handlers": self.retry_handlers}
-
-        if self._token:
-            conn_params["token"] = self._token
-        elif conn:
-            if not conn.password:
-                raise AirflowNotFoundException(
-                    f"Connection ID {self.slack_conn_id!r} does not contain password (Slack API Token)."
-                )
-            conn_params["token"] = conn.password
-
+        conn = self.get_connection(self.slack_conn_id)
+        if not conn.password:
+            raise AirflowNotFoundException(
+                f"Connection ID {self.slack_conn_id!r} does not contain password (Slack API Token)."
+            )
+        conn_params: dict[str, Any] = {"token": conn.password, "retry_handlers": self.retry_handlers}
         extra_config = ConnectionExtraConfig(
-            conn_type=self.conn_type,
-            conn_id=conn.conn_id if conn else None,
-            extra=conn.extra_dejson if conn else {},
+            conn_type=self.conn_type, conn_id=conn.conn_id, extra=conn.extra_dejson
         )
-
         # Merge Hook parameters with Connection config
         conn_params.update(
             {
@@ -190,41 +163,10 @@ class SlackHook(BaseHook):
                 "proxy": self.proxy or extra_config.get("proxy", default=None),
             }
         )
-
         # Add additional client args
         conn_params.update(self.extra_client_args)
-        if "logger" not in conn_params:
-            conn_params["logger"] = self.log
-
         return {k: v for k, v in conn_params.items() if v is not None}
 
-    @cached_property
-    def token(self) -> str:
-        warnings.warn(
-            "`SlackHook.token` property deprecated and will be removed in a future releases.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self._get_conn_params()["token"]
-
-    def __get_token(self, token: Any, slack_conn_id: Any) -> str:
-        warnings.warn(
-            "`SlackHook.__get_token` method deprecated and will be removed in a future releases.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        if token is not None:
-            return token
-
-        if slack_conn_id is not None:
-            conn = self.get_connection(slack_conn_id)
-
-            if not getattr(conn, "password", None):
-                raise AirflowException("Missing token(password) in Slack connection")
-            return conn.password
-
-        raise AirflowException("Cannot get token: No valid Slack token nor slack_conn_id supplied.")
-
     def call(self, api_method: str, **kwargs) -> SlackResponse:
         """
         Calls Slack WebClient `WebClient.api_call` with given arguments.
@@ -294,6 +236,128 @@ class SlackHook(BaseHook):
             channels=channels,
         )
 
+    def send_file_v2(
+        self,
+        *,
+        channel_id: str | None = None,
+        file_uploads: FileUploadTypeDef | list[FileUploadTypeDef],
+        initial_comment: str | None = None,
+    ) -> SlackResponse:
+        """
+        Sends one or more files to a Slack channel using the Slack SDK Client method `files_upload_v2`.
+
+        :param channel_id: The ID of the channel to send the file to.
+            If omitting this parameter, then file will send to workspace.
+        :param file_uploads: The file(s) specification to upload.
+        :param initial_comment: The message text introducing the file in specified ``channel``.
+        """
+        if channel_id and channel_id.startswith("#"):
+            retried_channel_id = self.get_channel_id(channel_id[1:])
+            warnings.warn(
+                "The method `files_upload_v2` in the Slack SDK Client expects a Slack Channel ID, "
+                f"but received a Slack Channel Name. To resolve this, consider replacing {channel_id!r} "
+                f"with the corresponding Channel ID {retried_channel_id!r}.",
+                UserWarning,
+                stacklevel=2,
+            )
+            channel_id = retried_channel_id
+
+        if not isinstance(file_uploads, list):
+            file_uploads = [file_uploads]
+        for file_upload in file_uploads:
+            if not file_upload.get("filename"):
+                # Some of early version of Slack SDK (such as 3.19.0) raise an error if ``filename`` not set.
+                file_upload["filename"] = "Uploaded file"
+
+        return self.client.files_upload_v2(
+            channel=channel_id,
+            # mypy doesn't happy even if TypedDict used instead of dict[str, Any]
+            # see: https://github.com/python/mypy/issues/4976
+            file_uploads=file_uploads,  # type: ignore[arg-type]
+            initial_comment=initial_comment,
+        )
+
+    def send_file_v1_to_v2(
+        self,
+        *,
+        channels: str | Sequence[str] | None = None,
+        file: str | Path | None = None,
+        content: str | None = None,
+        filename: str | None = None,
+        initial_comment: str | None = None,
+        title: str | None = None,
+        filetype: str | None = None,
+    ) -> list[SlackResponse]:
+        """
+        Smooth transition between ``send_file`` and ``send_file_v2`` methods.
+
+        :param channels: Comma-separated list of channel names or IDs where the file will be shared.
+            If omitting this parameter, then file will send to workspace.
+            File would be uploaded for each channel individually.
+        :param file: Path to file which need to be sent.
+        :param content: File contents. If omitting this parameter, you must provide a file.
+        :param filename: Displayed filename.
+        :param initial_comment: The message text introducing the file in specified ``channels``.
+        :param title: Title of the file.
+        :param filetype: A file type identifier.
+        """
+        if not exactly_one(file, content):
+            raise ValueError("Either `file` or `content` must be provided, not both.")
+        if file:
+            file = Path(file)
+            file_uploads: FileUploadTypeDef = {"file": file.__fspath__(), "filename": filename or file.name}
+        else:
+            file_uploads = {"content": content, "filename": filename}
+
+        file_uploads.update({"title": title, "snippet_type": filetype})
+
+        if channels:
+            if isinstance(channels, str):
+                channels = channels.split(",")
+            channels_to_share: list[str | None] = list(map(str.strip, channels))
+        else:
+            channels_to_share = [None]
+
+        responses = []
+        for channel in channels_to_share:
+            responses.append(
+                self.send_file_v2(
+                    channel_id=channel, file_uploads=file_uploads, initial_comment=initial_comment
+                )
+            )
+        return responses
+
+    def get_channel_id(self, channel_name: str) -> str:
+        """
+        Retrieves a Slack channel id by a channel name.
+
+        It continuously iterates over all Slack channels (public and private)
+        until it finds the desired channel name in addition cache results for further usage.
+
+        .. seealso::
+            https://api.slack.com/methods/conversations.list
+
+        :param channel_name: The name of the Slack channel for which ID has to be found.
+        """
+        next_cursor = None
+        while not (channel_id := self._channels_mapping.get(channel_name)):
+            res = self.client.conversations_list(cursor=next_cursor, types="public_channel,private_channel")
+            if TYPE_CHECKING:
+                # Slack SDK response type too broad, this should make mypy happy
+                assert isinstance(res.data, dict)
+
+            for channel_data in res.data.get("channels", []):
+                self._channels_mapping[channel_data["name"]] = channel_data["id"]
+
+            if not (next_cursor := res.data.get("response_metadata", {}).get("next_cursor")):
+                channel_id = self._channels_mapping.get(channel_name)
+                break
+
+        if not channel_id:
+            msg = f"Unable to find slack channel with name: {channel_name!r}"
+            raise LookupError(msg)
+        return channel_id
+
     def test_connection(self):
         """Tests the Slack API connection.
 
@@ -346,7 +410,6 @@ class SlackHook(BaseHook):
         }
 
     @classmethod
-    @_ensure_prefixes(conn_type="slack")
     def get_ui_field_behaviour(cls) -> dict[str, Any]:
         """Returns custom field behaviour."""
         return {
