@@ -16,15 +16,17 @@
 # specific language governing permissions and limitations
 # under the License.
 """
-Secrets framework provides means of getting connection objects from various sources, e.g. the following:
+Secrets framework provides means of getting connection objects from various sources.
 
-    * Environment variables
-    * Metastore database
-    * AWS SSM Parameter store
+The following sources are available:
+
+* Environment variables
+* Metastore database
+* Local Filesystem Secrets Backend
 """
 from __future__ import annotations
 
-__all__ = ['BaseSecretsBackend', 'DEFAULT_SECRETS_SEARCH_PATH']
+__all__ = ["BaseSecretsBackend", "DEFAULT_SECRETS_SEARCH_PATH"]
 
 from airflow.secrets.base_secrets import BaseSecretsBackend
 
