@@ -25,27 +25,26 @@ from typing import TYPE_CHECKING
 from airflow.configuration import conf
 from airflow.executors.executor_loader import ExecutorLoader
 from airflow.utils.session import find_session_idx, provide_session
-from airflow.utils.state import State
+from airflow.utils.state import TaskInstanceState
 
 if TYPE_CHECKING:
     from sqlalchemy.orm import Session
 
+    from airflow.models.taskinstance import TaskInstance
+
 log = logging.getLogger(__name__)
 
 
 class DummySentry:
     """Blank class for Sentry."""
 
-    @classmethod
-    def add_tagging(cls, task_instance):
+    def add_tagging(self, task_instance):
         """Blank function for tagging."""
 
-    @classmethod
-    def add_breadcrumbs(cls, task_instance, session: Session | None = None):
+    def add_breadcrumbs(self, task_instance, session: Session | None = None):
         """Blank function for breadcrumbs."""
 
-    @classmethod
-    def enrich_errors(cls, run):
+    def enrich_errors(self, run):
         """Blank function for formatting a TaskInstance._run_raw_task."""
         return run
 
@@ -76,7 +75,6 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
                 "in_app_exclude",
                 "ignore_errors",
                 "before_breadcrumb",
-                "transport",
             )
         )
 
@@ -89,7 +87,7 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
             # LoggingIntegration is set by default.
             integrations = [sentry_flask]
 
-            executor_class, _ = ExecutorLoader.import_default_executor_cls()
+            executor_class, _ = ExecutorLoader.import_default_executor_cls(validate=False)
 
             if executor_class.supports_sentry:
                 from sentry_sdk.integrations.celery import CeleryIntegration
@@ -114,6 +112,7 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
                     )
 
                 sentry_config_opts["before_send"] = conf.getimport("sentry", "before_send", fallback=None)
+                sentry_config_opts["transport"] = conf.getimport("sentry", "transport", fallback=None)
 
             if dsn:
                 sentry_sdk.init(dsn=dsn, integrations=integrations, **sentry_config_opts)
@@ -123,7 +122,7 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
                 sentry_sdk.init(integrations=integrations, **sentry_config_opts)
 
         def add_tagging(self, task_instance):
-            """Function to add tagging for a task_instance."""
+            """Add tagging for a task_instance."""
             dag_run = task_instance.dag_run
             task = task_instance.task
 
@@ -137,13 +136,17 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
                 scope.set_tag("operator", task.__class__.__name__)
 
         @provide_session
-        def add_breadcrumbs(self, task_instance, session=None):
-            """Function to add breadcrumbs inside of a task_instance."""
+        def add_breadcrumbs(
+            self,
+            task_instance: TaskInstance,
+            session: Session | None = None,
+        ) -> None:
+            """Add breadcrumbs inside of a task_instance."""
             if session is None:
                 return
             dr = task_instance.get_dagrun(session)
             task_instances = dr.get_task_instances(
-                state={State.SUCCESS, State.FAILED},
+                state={TaskInstanceState.SUCCESS, TaskInstanceState.FAILED},
                 session=session,
             )
 
@@ -157,8 +160,8 @@ if conf.getboolean("sentry", "sentry_on", fallback=False):
         def enrich_errors(self, func):
             """
             Decorate errors.
-            Wrap TaskInstance._run_raw_task and LocalTaskJob._run_mini_scheduler_on_child_tasks
-            to support task specific tags and breadcrumbs.
+
+            Wrap TaskInstance._run_raw_task to support task specific tags and breadcrumbs.
             """
             session_args_idx = find_session_idx(func)
 
