@@ -89,7 +89,7 @@ def _promote_new_flags():
         console.print("[yellow]Still too slow?[/]")
         console.print()
     console.print("You can only build one documentation package:")
-    console.print("    [info]breeze build-docs --package-filter <PACKAGE-NAME>[/]")
+    console.print("    [info]breeze build-docs <PACKAGES>[/]")
     console.print()
     console.print("This usually takes from [yellow]20 seconds[/] to [yellow]2 minutes[/].")
     console.print()
@@ -128,7 +128,9 @@ def _get_parser():
         "--package-filter",
         action="append",
         help=(
-            "Filter specifying for which packages the documentation is to be built. Wildcard are supported."
+            "Filter(s) to use more than one can be specified. You can use glob pattern matching the "
+            "full package name, for example `apache-airflow-providers-*`. Useful when you want to select"
+            "several similarly named packages together."
         ),
     )
     parser.add_argument("--docs-only", dest="docs_only", action="store_true", help="Only build documentation")
@@ -430,7 +432,6 @@ def main():
     disable_provider_checks = args.disable_provider_checks
     disable_checks = args.disable_checks
     package_filters = args.package_filter
-
     with with_group("Available packages"):
         for pkg in sorted(available_packages):
             console.print(f" - {pkg}")
@@ -438,7 +439,6 @@ def main():
     if package_filters:
         console.print("Current package filters: ", package_filters)
     current_packages = process_package_filters(available_packages, package_filters)
-
     with with_group("Fetching inventories"):
         # Inventories that could not be retrieved should be built first. This may mean this is a
         # new package.
