@@ -17,18 +17,20 @@
 from __future__ import annotations
 
 import logging
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 from docutils import nodes
-from docutils.nodes import Node, system_message
 
 # No stub exists for docutils.parsers.rst.directives. See https://github.com/python/typeshed/issues/5755.
 from docutils.parsers.rst import Directive, directives  # type: ignore[attr-defined]
 from docutils.parsers.rst.roles import code_role
-from sphinx.application import Sphinx
 from sphinx.transforms import SphinxTransform
 from sphinx.transforms.post_transforms.code import HighlightLanguageTransform
 
+if TYPE_CHECKING:
+    from docutils.utils import SystemMessage
+    from sphinx.application import Sphinx
+
 LOGGER = logging.getLogger(__name__)
 
 OriginalCodeBlock: Directive = directives._directives["code-block"]
@@ -84,10 +86,10 @@ class SubstitutionCodeBlockTransform(SphinxTransform):
             node.rawsource = node.astext()
 
 
-def substitution_code_role(*args, **kwargs) -> tuple[list[Node], list[system_message]]:
+def substitution_code_role(*args, **kwargs) -> tuple[list, list[SystemMessage]]:
     """Decorate an inline code so that SubstitutionCodeBlockTransform will notice it"""
     [node], system_messages = code_role(*args, **kwargs)
-    node[_SUBSTITUTION_OPTION_NAME] = True
+    node[_SUBSTITUTION_OPTION_NAME] = True  # type: ignore[index]
 
     return [node], system_messages
 
