@@ -65,7 +65,7 @@ class TestFlowerDeployment:
             values=values,
             show_only=["templates/flower/flower-deployment.yaml"],
         )
-        expected_result = revision_history_limit if revision_history_limit else global_revision_history_limit
+        expected_result = revision_history_limit or global_revision_history_limit
         assert jmespath.search("spec.revisionHistoryLimit", docs[0]) == expected_result
 
     @pytest.mark.parametrize(
@@ -164,6 +164,17 @@ class TestFlowerDeployment:
             "spec.template.spec.containers[0].readinessProbe.exec.command", docs[0]
         )
 
+    def test_scheduler_name(self):
+        docs = render_chart(
+            values={"flower": {"enabled": True}, "schedulerName": "airflow-scheduler"},
+            show_only=["templates/flower/flower-deployment.yaml"],
+        )
+
+        assert "airflow-scheduler" == jmespath.search(
+            "spec.template.spec.schedulerName",
+            docs[0],
+        )
+
     def test_should_create_valid_affinity_tolerations_and_node_selector(self):
         docs = render_chart(
             values={
